@@ -1,7 +1,7 @@
 package Text::Table::Any;
 
-our $DATE = '2016-10-19'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-12-29'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 #IFUNBUILT
 # # use 5.010001;
@@ -46,6 +46,14 @@ sub table {
         require Text::Table::CSV;
         return Text::Table::CSV::table(
             rows => $rows);
+    } elsif ($backend eq 'Text::Table::HTML') {
+        require Text::Table::HTML;
+        return Text::Table::HTML::table(
+            rows => $rows, header_row => $header_row);
+    } elsif ($backend eq 'Text::Table::HTML::DataTables') {
+        require Text::Table::HTML::DataTables;
+        return Text::Table::HTML::DataTables::table(
+            rows => $rows, header_row => $header_row);
     } elsif ($backend eq 'Text::ANSITable') {
         require Text::ANSITable;
         my $t = Text::ANSITable->new(
@@ -124,7 +132,7 @@ Text::Table::Any - Generate text table using one of several backends
 
 =head1 VERSION
 
-This document describes version 0.05 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2016-10-19.
+This document describes version 0.06 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2016-12-29.
 
 =head1 SYNOPSIS
 
